#[non_exhaustive]#[repr(u8)]pub enum Variant {
NCS = 0,
RFC4122 = 1,
Microsoft = 2,
Future = 3,
}Expand description
The reserved variants of UUIDs.
Unlike the version field, which is a strict set of values, the variant behaves more like a mask. Multiple bit patterns in a UUID’s variant field may correspond to the same variant value.
References
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NCS = 0
Reserved by the NCS for backward compatibility.
The Nil UUID will return this variant.
RFC4122 = 1
The variant specified in RFC9562.
The majority of UUIDs use this variant.
Microsoft = 2
Reserved by Microsoft for backward compatibility.
Future = 3
Reserved for future expansion.
The Max UUID will return this variant.